@@ -31,7 +31,7 @@ class StationB(Station):
         drop_loc_r: float = 20,
         drop_loc_y: float = 0,
         drop_threshold: int = 5000,
-        elute_air_gap: float = 20,
+        elute_air_gap: float = 5,
         elute_aspiration_rate: float = 50,
         elute_dispense_rate: float = 50,
         elute_incubate: bool = True,
@@ -51,6 +51,7 @@ class StationB(Station):
         magplate_model: str = 'nest_96_wellplate_2ml_deep',
         metadata: Optional[dict] = None,
         num_samples: int = 96,
+        pipette_max_volume: float = 200,
         samples_per_col: int = 8,
         skip_delay: bool = False,
         supernatant_removal_air_gap: float = 5,
@@ -59,6 +60,8 @@ class StationB(Station):
         supernatant_removal_dispense_rate: float = 200,
         supernatant_removal_height: float = 0.5,
         supernatant_removal_last_transfer_max_vol: float = 190,
+        supernatant_removal_side: float = 1.5,
+        supernatant_removal_side_last_transfer: float = 0.5,
         starting_vol: float = 380,
         tempdeck_slot: str = '1',
         tempdeck_temp: float = 4,
@@ -124,6 +127,7 @@ class StationB(Station):
         :param magplate_model: Magnetic plate model
         :param metadata: protocol metadata
         :param num_samples: The number of samples that will be loaded on the station B
+        :param pipette_max_volume: The maximum volume in ul that the pipette (considering tip) can aspirate
         :param samples_per_col: The number of samples in a column of the destination plate
         :param skip_delay: If True, pause instead of delay.
         :param supernatant_removal_air_gap: Air gap when removing the supernatant in uL
@@ -205,12 +209,15 @@ class StationB(Station):
         self._magheight = magheight
         self._magheight_load = magheight_load
         self._magplate_model = magplate_model
+        self._pipette_max_volume = pipette_max_volume
         self._supernatant_removal_air_gap = supernatant_removal_air_gap
         self._supernatant_removal_aspiration_rate = supernatant_removal_aspiration_rate
         self._supernatant_removal_aspiration_rate_first_phase = supernatant_removal_aspiration_rate_first_phase
         self._supernatant_removal_dispense_rate = supernatant_removal_dispense_rate
         self._supernatant_removal_height = supernatant_removal_height
         self._supernatant_removal_last_transfer_max_vol = supernatant_removal_last_transfer_max_vol
+        self._supernatant_removal_side = supernatant_removal_side
+        self._supernatant_removal_side_last_transfer = supernatant_removal_side_last_transfer
         self._starting_vol = starting_vol
         self._tempdeck_slot = tempdeck_slot
         self._tempdeck_temp = tempdeck_temp
@@ -332,23 +339,27 @@ class StationB(Station):
             self.dual_pause("check module")
 
     def remove_supernatant(self, vol: float, stage: str = "remove supernatant"):
-        num_trans = math.ceil((vol - self._vol_last_trans) / self._bind_max_transfer_vol)
-        vol_per_trans = ((vol - self._vol_last_trans) / num_trans) if num_trans else 0
+        self._ctx.comment("Pipette volume: {}".format(self._pipette_max_volume))
+
+        num_trans, vol_per_trans = uniform_divide(vol-self._vol_last_trans,
+                                                  self._pipette_max_volume - self._supernatant_removal_air_gap)
 
         for i, m in enumerate(self.mag_samples_m):
+            self._ctx.comment("Supernatant side: {}, {}".format(self._supernatant_removal_side,
+                                                                self._supernatant_removal_side_last_transfer))
             self._m300.flow_rate.aspirate = self._supernatant_removal_aspiration_rate_first_phase
             self._m300.flow_rate.dispense = self._supernatant_removal_dispense_rate
-            well_with_volume = WellWithVolume(m, vol)
+            well_with_volume = WellWithVolume(m, vol, min_height=self._h_bottom)
             if self.run_stage("{} {}/{}".format(stage, i + 1, len(self.mag_samples_m))):
                 self.pick_up(self._m300)
                 self._ctx.comment("Supernatant removal: {} transfer with {}ul each.".format(num_trans, vol_per_trans))
+                side = -1 if i % 2 == 0 else 1
                 for _ in range(num_trans):
                     if self._m300.current_volume > 0:
                         self._m300.dispense(self._m300.current_volume, m.top())                   
                     self._m300.move_to(m.center())
                     height = well_with_volume.extract_vol_and_get_height(vol_per_trans)
-                    side = -1 if i % 2 == 0 else 1
-                    loc = m.bottom(height).move(Point(x=side * 2))
+                    loc = m.bottom(height).move(Point(x=side * self._supernatant_removal_side))
                     self.logger.info("Aspirate at: {:.2f}".format(height))
                     self._m300.transfer(vol_per_trans, loc, self._waste, new_tip='never', air_gap=self._supernatant_removal_air_gap)
                     self._m300.air_gap(self._supernatant_removal_air_gap)
@@ -362,17 +373,16 @@ class StationB(Station):
                 for j in range(self._n_bottom):
                     aspirate_height = self._h_bottom - (j)*(self._h_bottom/(self._n_bottom-1)) # expecting aspirated height
                     self.logger.info("Aspirating at {:.2f}".format(aspirate_height))
-                    side = -1 if i % 2 == 0 else 1
-                    loc = m.bottom(aspirate_height).move(Point(x=side * 2))
+                    loc = m.bottom(aspirate_height).move(Point(x=side * self._supernatant_removal_side_last_transfer))
                     self._m300.aspirate(self._supernatant_removal_last_transfer_max_vol/self._n_bottom, loc)
 
                 back_step = 0.1
-                n_back_step = 3
+                n_back_step = self._n_bottom
 
                 for _ in range(n_back_step):
                     aspirate_height = aspirate_height + back_step
                     self.logger.info("Moving up at {:.2f}".format(aspirate_height))
-                    loc = m.bottom(aspirate_height).move(Point(x=side * 2))
+                    loc = m.bottom(aspirate_height).move(Point(x=side * self._supernatant_removal_side_last_transfer))
                     self._m300.move_to(loc)
 
                 self._m300.air_gap(self._supernatant_removal_air_gap)
